@@ -114,6 +114,19 @@ impl<'main> BatPrinter<'main> {
         self.assets.themes()
     }
 
+    pub fn list_themes(&mut self) -> Result<()> {
+        let sample = File::sample_file();
+        let mut themes: Vec<_> = self.assets.themes().collect();
+        themes.sort_unstable();
+        for theme in themes.into_iter() {
+            println!("\x1b[1m{:?}\x1b[0m", theme);
+            self.config.theme = theme.to_string();
+            self.print(sample.clone())?;
+            println!();
+        }
+        Ok(())
+    }
+
     pub fn print(&self, file: File) -> Result<()> {
         if file.chunks.is_empty() || file.line_matches.is_empty() {
             return Ok(()); // Ensure to print some match
@@ -141,23 +154,25 @@ impl<'main> BatPrinter<'main> {
         let ranges = file
             .chunks
             .iter()
-            .map(|(s, e)| LineRange::new(*s as usize, *e as usize))
-            .collect();
-        config.visible_lines = VisibleLines::Ranges(LineRanges::from(ranges));
-
-        let input =
-            Input::from_reader(Box::new(file.contents.as_ref())).with_name(Some(&file.path));
-
-        let ranges = file.line_matches.iter().map(|m| {
-            let n = m.line_number as usize;
-            LineRange::new(n, n)
-        });
-
+            .map(|(s, e)| LineRange::new(*s as usize, *e as usize));
         let ranges = if self.opts.first_only {
             ranges.take(1).collect()
         } else {
             ranges.collect()
         };
+        config.visible_lines = VisibleLines::Ranges(LineRanges::from(ranges));
+
+        let input =
+            Input::from_reader(Box::new(file.contents.as_ref())).with_name(Some(&file.path));
+
+        let ranges = file
+            .line_matches
+            .iter()
+            .map(|m| {
+                let n = m.line_number as usize;
+                LineRange::new(n, n)
+            })
+            .collect();
 
         config.highlighted_lines = HighlightedLineRanges(LineRanges::from(ranges));
 
